# borisml

The `borisml` Python package has been renamed to `lightly` and is since deprecated.

Please check out `lightly`:
* [PIP package](https://pypi.org/project/lightly/)
* [Documentation](https://lightly.readthedocs.io/en/latest/)
* [Github](https://github.com/lightly-ai/lightly)
